@@ -1,5 +1,5 @@
 package CPAN::ReleaseHistory::Release;
-$CPAN::ReleaseHistory::Release::VERSION = '0.10';
+$CPAN::ReleaseHistory::Release::VERSION = '0.11';
 use Moo;
 use CPAN::DistnameInfo;
 
@@ -7,6 +7,7 @@ has 'path'      => (is => 'ro');
 has 'timestamp' => (is => 'ro');
 has 'size'      => (is => 'ro');
 has 'distinfo'  => (is => 'lazy');
+has 'date'      => (is => 'lazy');
 
 sub _build_distinfo
 {
@@ -15,4 +16,12 @@ sub _build_distinfo
     return CPAN::DistnameInfo->new($self->path);
 }
 
+sub _build_date
+{
+    my $self = shift;
+    my @gmt  = gmtime($self->timestamp);
+
+    return sprintf('%d-%.2d-%.2d', $gmt[5]+1900, $gmt[4]+1, $gmt[3]);
+}
+
 1;
